# pydantic-supervisor

Pydantic models for supervisor

[![Build Status](https://github.com/airflow-laminar/pydantic-supervisor/actions/workflows/build.yml/badge.svg?branch=main&event=push)](https://github.com/airflow-laminar/pydantic-supervisor/actions/workflows/build.yml)
[![codecov](https://codecov.io/gh/airflow-laminar/pydantic-supervisor/branch/main/graph/badge.svg)](https://codecov.io/gh/airflow-laminar/pydantic-supervisor)
[![License](https://img.shields.io/github/license/airflow-laminar/pydantic-supervisor)](https://github.com/airflow-laminar/pydantic-supervisor)
[![PyPI](https://img.shields.io/pypi/v/pydantic-supervisor.svg)](https://pypi.python.org/pypi/pydantic-supervisor)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/airflow-laminar/pydantic-supervisor/main?urlpath=lab)

## Overview
Wrapper for [supervisor-pydantic](https://github.com/airflow-laminar/supervisor-pydantic).

> [!NOTE]
> This library was generated using [copier](https://copier.readthedocs.io/en/stable/) from the [Base Python Project Template repository](https://github.com/python-project-templates/base).
